#!/usr/bin/python3

# SPDX-FileCopyrightText: 2021 Pino Toscano <pino@debian.org>
# SPDX-License-Identifier: GPL-2.0-or-later

import glob
import os
import shutil
import sys

# known language mappings for MySQL/MariaDB language files;
# "english" is not present here, as it is handled on its own
language_mappings = {
    'czech': 'cs',
    'danish': 'da',
    'dutch': 'nl',
    'estonian': 'et',
    'french': 'fr',
    'german': 'de',
    'greek': 'el',
    'hindi': 'hi',
    'hungarian': 'hu',
    'italian': 'it',
    'japanese': 'ja',
    'korean': 'ko',
    'norwegian': 'nb',
    'norwegian-ny': 'nn',
    'polish': 'pl',
    'portuguese': 'pt',
    'romanian': 'ro',
    'russian': 'ru',
    'serbian': 'sr',
    'slovak': 'sk',
    'spanish': 'es',
    'swedish': 'sv',
    'ukrainian': 'uk',
}


def fail(msg):
    print('ERROR: ' + msg, file=sys.stderr)
    sys.exit(1)


def do_copy(srcfile, destdir):
    destfile = os.path.join(destdir, 'errmsg.sys')
    os.makedirs(destdir, exist_ok=True)
    print('Copying %s -> %s' % (srcfile, destfile))
    shutil.copy2(srcfile, destfile)


if len(sys.argv) != 3:
    fail('syntax: %s SOURCE_DIR DESTINATION_DIR' % sys.argv[0])

source_dir = sys.argv[1]
destination_dir = sys.argv[2]

errmsg_files = glob.glob(os.path.join(source_dir, '*', 'errmsg.sys'))
english_errmsg = None
language_files = []
unhandled_files = []
for errmsg_file in errmsg_files:
    language = os.path.basename(os.path.dirname(errmsg_file))
    if language == 'english':
        english_errmsg = errmsg_file
        continue
    try:
        language_files.append((errmsg_file, language_mappings[language]))
    except KeyError:
        unhandled_files.append(errmsg_file)

if not english_errmsg:
    fail('missing english errmsg.sys')

for uf in sorted(unhandled_files):
    print('WARNING: unhandled localized file: %s' % uf, file=sys.stderr)

do_copy(english_errmsg, destination_dir)
for errmsg_file, language in sorted(language_files):
    destdir = os.path.join(destination_dir, 'l10n', language)
    do_copy(errmsg_file, destdir)
